==> ejc-procost-impl-3.0.0-20220817.033541-96-sources.jar: com/ejianc/business/procost/bean/UnitDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 主材量价对比子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_unit_detail")
public class UnitDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="unit_id")
    private Long unitId; // 计量单位主键
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="conversion_unit_name")
    private String conversionUnitName; // 转换计量单位
    @TableField(value="memo")
    private String memo; // 描述
    @TableField(value="scale_factor")
    private BigDecimal scaleFactor; // 换算系数


    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getConversionUnitName() {
        return conversionUnitName;
    }

    public void setConversionUnitName(String conversionUnitName) {
        this.conversionUnitName = conversionUnitName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getScaleFactor() {
        return scaleFactor;
    }

    public void setScaleFactor(BigDecimal scaleFactor) {
        this.scaleFactor = scaleFactor;
    }
    
}

==> ejc-procost-impl-3.0.0-20230607.061412-183-sources.jar: com/ejianc/business/procost/bean/UnitDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 主材量价对比子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_unit_detail")
public class UnitDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="detail_unit_id")
    private Long detailUnitId; // 计量单位主键
    @TableField(value="detail_unit_name")
    private String detailUnitName; // 计量单位
    @TableField(value="conversion_unit_name")
    private String conversionUnitName; // 转换计量单位
    @TableField(value="memo")
    private String memo; // 描述
    @TableField(value="scale_factor")
    private BigDecimal scaleFactor; // 换算系数


    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getDetailUnitId() {
        return detailUnitId;
    }

    public void setDetailUnitId(Long detailUnitId) {
        this.detailUnitId = detailUnitId;
    }

    public String getDetailUnitName() {
        return detailUnitName;
    }

    public void setDetailUnitName(String detailUnitName) {
        this.detailUnitName = detailUnitName;
    }

    public String getConversionUnitName() {
        return conversionUnitName;
    }

    public void setConversionUnitName(String conversionUnitName) {
        this.conversionUnitName = conversionUnitName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getScaleFactor() {
        return scaleFactor;
    }

    public void setScaleFactor(BigDecimal scaleFactor) {
        this.scaleFactor = scaleFactor;
    }
    
}
